stac.nonparametric_tests.quade_test — STAC Release Candidate documentation

### Navigation

- index
- STAC Release Candidate documentation »

# stac.nonparametric_tests.quade_test

`stac.nonparametric_tests.` `quade_test`(*args)

  Performs a Quade ranking test. Tests the hypothesis that in a set of k dependent samples groups (where k >= 2) at least two of the groups represent populations with different median values. The difference with a friedman test is that it uses the median for each sample to wiehgt the ranking.

  Parameters: | sample1, sample2, ... : array_like The sample measurements for each group.
  Returns: | F-value : float The computed F-value of the test. p-value : float The associated p-value from the F-distribution. rankings : array_like The ranking for each group. pivots : array_like The pivotal quantities for each group.

  References

  4. Quade, Using weighted rankings in the analysis of complete blocks with additive block effects, Journal of the American Statistical Association 74 (1979) 680–683.

### Navigation

- index
- STAC Release Candidate documentation »